WalkMyGraph (WMG) is a specification by example software development using Knowledge Graph Traversals and Named Parameterized Queries
Created by BITPlan
Copyright(c) 2026 BITPlan GmbH, Willich, Germany https://www.bitplan.com

| | |
| :--- | :--- |
| **PyPi** | [![PyPI Status](https://img.shields.io/pypi/v/walkmygraph.svg)](https://pypi.python.org/pypi/walkmygraph/) [![License](https://img.shields.io/github/license/BITPlan/WalkMyGraph.svg)](https://www.apache.org/licenses/LICENSE-2.0) [![pypi](https://img.shields.io/pypi/pyversions/walkmygraph)](https://pypi.org/project/walkmygraph/) [![format](https://img.shields.io/pypi/format/walkmygraph)](https://pypi.org/project/walkmygraph/) [![downloads](https://img.shields.io/pypi/dd/walkmygraph)](https://pypi.org/project/walkmygraph/) |
| **GitHub** | [![Github Actions Build](https://github.com/BITPlan/WalkMyGraph/actions/workflows/build.yml/badge.svg)](https://github.com/BITPlan/WalkMyGraph/actions/workflows/build.yml) [![Release](https://img.shields.io/github/v/release/BITPlan/WalkMyGraph)](https://github.com/BITPlan/WalkMyGraph/releases) [![Contributors](https://img.shields.io/github/contributors/BITPlan/WalkMyGraph)](https://github.com/BITPlan/WalkMyGraph/graphs/contributors) [![Last Commit](https://img.shields.io/github/last-commit/BITPlan/WalkMyGraph)](https://github.com/BITPlan/WalkMyGraph/commits/) [![GitHub issues](https://img.shields.io/github/issues/BITPlan/WalkMyGraph.svg)](https://github.com/BITPlan/WalkMyGraph/issues) [![GitHub closed issues](https://img.shields.io/github/issues-closed/BITPlan/WalkMyGraph.svg)](https://github.com/BITPlan/WalkMyGraph/issues/?q=is%3Aissue+is%3Aclosed) |
| **Code** | [![style-black](https://img.shields.io/badge/%20style-black-000000.svg)](https://github.com/psf/black) [![imports-isort](https://img.shields.io/badge/%20imports-isort-%231674b1)](https://pycqa.github.io/isort/) |
| **Docs** | [![API Docs](https://img.shields.io/badge/API-Documentation-blue)](https://BITPlan.github.io/WalkMyGraph/) [![formatter-docformatter](https://img.shields.io/badge/%20formatter-docformatter-fedcba.svg)](https://github.com/PyCQA/docformatter) [![style-google](https://img.shields.io/badge/%20style-google-3666d6.svg)](https://google.github.io/styleguide/pyguide.html#s3.8-comments-and-docstrings) |

# Prototypes
- https://github.com/WolfgangFahl/DualViewKnowledgeGraphExplorer

# Papers
- https://github.com/WolfgangFahl/DualViewKnowledgeGraphExplorerPaper

# Docs
[Wiki](https://wiki.bitplan.com/index.php/WalkMyGraph)
